pub fn render(
tree: &DumpTree,
buf: &[u8],
opts: &RenderOpts,
w: &mut impl Write,
) -> Result<()>Expand description
Render tree as an annotated hexdump.
buf must be the buffer that was passed to super::annotate_tile.
pub fn render(
tree: &DumpTree,
buf: &[u8],
opts: &RenderOpts,
w: &mut impl Write,
) -> Result<()>Render tree as an annotated hexdump.
buf must be the buffer that was passed to super::annotate_tile.