Module encoder

Module encoder 

Structs

EncodedUnknown
Owned variant of Unknown.
Encoder
Stateful encoder that accumulates encoded layer bytes.
EncoderConfig
Global encoder settings controlling which optimization strategies are attempted.

Enums

SortStrategy
Controls how features inside a layer are reordered before encoding.
StagedId
Staged ID column (encode-side, fully owned).