EncoderConfig

Struct EncoderConfig 

pub struct EncoderConfig {
    pub tessellate: bool,
    pub try_spatial_morton_sort: bool,
    pub try_spatial_hilbert_sort: bool,
    pub try_id_sort: bool,
    pub allow_fsst: bool,
    pub allow_fpf: bool,
    pub allow_shared_dict: bool,
}
Global encoder settings controlling which optimization strategies are attempted.

Fields

tessellate: bool

Generate tessellation data for polygons and multi-polygons.

try_spatial_morton_sort: bool

Try sorting features by the Z-order (Morton) curve index of their first vertex.

try_spatial_hilbert_sort: bool

Try sorting features by the Hilbert curve index of their first vertex.

try_id_sort: bool

Try sorting features by their feature ID in ascending order.

allow_fsst: bool

Allow FSST string compression

allow_fpf: bool

Allow FastPFOR integer compression

allow_shared_dict: bool

Allow string grouping into shared dictionaries