pub enum EncDec<Raw, Parsed> {
Raw(Raw),
Parsed(Parsed),
ParsingFailed,
}Expand description
Shared wrapper for values that may still be in the original (raw) format or
already parsed (but still columnar).
Used by: Id, Geometry, Property, and eventually - SharedDictItem
Variants
Implementations
Sourceimpl<Raw: Decode<Parsed>, Parsed> EncDec<Raw, Parsed>
impl<Raw: Decode<Parsed>, Parsed> EncDec<Raw, Parsed>
Sourcepub fn decode(&mut self, decoder: &mut Decoder) -> MltResult<&mut Parsed>
pub fn decode(&mut self, decoder: &mut Decoder) -> MltResult<&mut Parsed>
Decode in place, replacing the raw value with the parsed result.
Sourcepub fn into_parsed(self, decoder: &mut Decoder) -> MltResult<Parsed>
pub fn into_parsed(self, decoder: &mut Decoder) -> MltResult<Parsed>
Consume and return the parsed value, decoding if currently raw.
pub fn as_parsed(&self) -> MltResult<&Parsed>
Sourceimpl<'a> EncDec<RawGeometry<'a>, GeometryValues>
impl<'a> EncDec<RawGeometry<'a>, GeometryValues>
Sourceimpl<'a> EncDec<RawId<'a>, IdValues>
impl<'a> EncDec<RawId<'a>, IdValues>
pub fn new_raw(presence: RawPresence<'a>, value: RawIdValue<'a>) -> Self