Layer

Enum Layer 

pub enum Layer<'a> {
    Tag01(Layer01<'a>),
    Unknown(Unknown<'a>),
}
A layer that can be one of the known types, or an unknown

Variants



Tag01(Layer01<'a>)

MVT-compatible layer (tag = 1)



Unknown(Unknown<'a>)

Unknown layer with tag, size, and value

Implementations

Source

impl<'a> Layer<'a>

pub fn as_layer01(&self) -> Option<&Layer01<'a>>

Returns the inner Layer01 if this is a Tag01 layer, or None otherwise.

pub fn as_layer01_mut(&mut self) -> Option<&mut Layer01<'a>>

Returns the inner Layer01 if this is a Tag01 layer, or None otherwise.

pub fn decoded_layer01_mut( &mut self, dec: &mut Decoder, ) -> Result<&mut Layer01<'a>, MltError>

pub fn from_bytes( input: &'a [u8], parser: &mut Parser, ) -> MltRefResult<'a, Layer<'a>>

Parse a single tuple that consists of size (varint), tag (varint), and value (bytes). Reserves memory for decoded data against the parser’s budget.

pub fn decode_all(&mut self, dec: &mut Decoder) -> MltResult<()>