pub struct FeatureWriter<'w, 'a> { /* private fields */ }Expand description
A feature being written into a LayerWriter.
Implementations
Sourceimpl<'a> FeatureWriter<'_, 'a>
impl<'a> FeatureWriter<'_, 'a>
pub fn id(&mut self, id: Option<u64>) -> &mut Self
Sourcepub fn property(
&mut self,
key: PropertyKey,
value: impl Into<PropValueRef<'a>>,
) -> MltResult<&mut Self>
pub fn property( &mut self, key: PropertyKey, value: impl Into<PropValueRef<'a>>, ) -> MltResult<&mut Self>
Sets the feature’s value in the key column, which must be of the value’s kind.
Sourcepub fn points(
&mut self,
coords: impl IntoIterator<Item = Coord<i32>>,
) -> MltResult<&mut Self>
pub fn points( &mut self, coords: impl IntoIterator<Item = Coord<i32>>, ) -> MltResult<&mut Self>
Adds points to a GeometryType::Point (which holds exactly one) or
GeometryType::MultiPoint feature.
Sourcepub fn line(
&mut self,
coords: impl IntoIterator<Item = Coord<i32>>,
) -> MltResult<&mut Self>
pub fn line( &mut self, coords: impl IntoIterator<Item = Coord<i32>>, ) -> MltResult<&mut Self>
Adds a line to a GeometryType::LineString (which holds exactly one) or
GeometryType::MultiLineString feature.
Sourcepub fn exterior_ring(
&mut self,
coords: impl IntoIterator<Item = Coord<i32>>,
) -> MltResult<&mut Self>
pub fn exterior_ring( &mut self, coords: impl IntoIterator<Item = Coord<i32>>, ) -> MltResult<&mut Self>
Starts a polygon of a GeometryType::Polygon (which holds exactly one) or
GeometryType::MultiPolygon feature with its exterior ring, which may be open or closed.
Sourcepub fn hole(
&mut self,
coords: impl IntoIterator<Item = Coord<i32>>,
) -> MltResult<&mut Self>
pub fn hole( &mut self, coords: impl IntoIterator<Item = Coord<i32>>, ) -> MltResult<&mut Self>
Adds a hole to the polygon the last Self::exterior_ring started, which may be open or
closed.