PhysicalEncoder

Enum PhysicalEncoder 

pub enum PhysicalEncoder {
    None,
    VarInt,
    FastPFOR,
}

Variants



None



VarInt

Can produce better results in combination with a heavyweight compression scheme like Gzip. Simple compression scheme where the encoding is easier to implement compared to FastPFOR.



FastPFOR

Preferred, tends to produce the best compression ratio and decoding performance.

Does not support u64/i64 integers

Implementations

Source

impl PhysicalEncoder

pub fn encode_u32s( self, values: Vec<u32>, ) -> Result<(EncodedStreamData, PhysicalEncoding), MltError>

Physically encode a u32 sequence into the appropriate EncodedStreamData variant.

pub fn encode_u64s( self, values: Vec<u64>, ) -> Result<(EncodedStreamData, PhysicalEncoding), MltError>

Physically encode a u64 sequence into the appropriate EncodedStreamData variant.