EncodedStream

Struct EncodedStream 

pub struct EncodedStream {
    pub meta: StreamMeta,
    pub data: EncodedStreamData,
}
Owned variant of RawStream.

Fields

meta: StreamMetadata: EncodedStreamData

Implementations

Source

impl EncodedStream

pub fn as_borrowed(&self) -> RawStream<'_>

Source

impl EncodedStream

pub fn empty_without_encoding() -> Self

Creates an empty stream

pub fn encode_bools(values: &[bool]) -> MltResult<Self>

Encode a boolean data stream: byte-RLE <- packed bitmap <- Vec<bool> Boolean streams always use byte-RLE encoding with LogicalEncoding::Rle metadata. The RleMeta values are computed by readers from the stream itself.

pub fn encode_presence(values: &[bool]) -> MltResult<Self>

Encode a presence/nullability stream

Identical to Self::encode_bools except the stream type is StreamType::Present

pub fn encode_f32(values: &[f32]) -> MltResult<Self>

Encodes f32s into a stream

pub fn encode_f64(values: &[f64]) -> MltResult<Self>

Encodes f64s into a stream

pub fn encode_i8s(values: &[i8], encoding: IntEncoder) -> MltResult<Self>

pub fn encode_u8s(values: &[u8], encoding: IntEncoder) -> MltResult<Self>

pub fn encode_i32s(values: &[i32], encoding: IntEncoder) -> MltResult<Self>

pub fn encode_u32s(values: &[u32], encoding: IntEncoder) -> MltResult<Self>

pub fn encode_u32s_of_type( values: &[u32], encoding: IntEncoder, stream_type: StreamType, ) -> MltResult<Self>

pub fn encode_i64s(values: &[i64], encoding: IntEncoder) -> MltResult<Self>

pub fn encode_u64s(values: &[u64], encoding: IntEncoder) -> MltResult<Self>

pub fn encode_strings_with_type<S: AsRef<str>>( values: &[S], length_encoding: IntEncoder, length_type: LengthType, dict_type: DictionaryType, ) -> MltResult<EncodedStringsEncoding>

Encode a sequence of strings into a length stream and a data stream.

pub fn encode_strings_fsst_with_type<S: AsRef<str>>( values: &[S], encoding: FsstStrEncoder, dict_type: DictionaryType, ) -> MltResult<EncodedStringsEncoding>

Encode a sequence of strings using FSST compression.

Produces 5 streams:

  1. Symbol lengths stream (Length, LengthType::Symbol)
  2. Symbol table data stream (Data, DictionaryType::Fsst)
  3. Value lengths stream (Length, LengthType::Dictionary)
  4. Compressed corpus stream (Data, dict_type)
  5. Offset indices stream (Offset, OffsetType::String)

The dictionary type of the compressed corpus stream is determined by the dict_type argument passed to this function.

Note: The FSST algorithm implementation may differ from Java’s, so the compressed output may not be byte-for-byte identical. Both implementations are semantically compatible and can decode each other’s output.

pub fn encode_strings_fsst_plain_with_type<S: AsRef<str>>( values: &[S], encoding: FsstStrEncoder, dict_type: DictionaryType, ) -> MltResult<EncodedStringsEncoding>

Encode strings with FSST (4 streams, no offset). For shared dictionary struct columns; each child has its own offset stream.