pub struct GeometryEncoder {Show 13 fields
pub meta: IntEncoder,
pub geometries: IntEncoder,
pub rings: IntEncoder,
pub rings2: IntEncoder,
pub no_rings: IntEncoder,
pub parts: IntEncoder,
pub parts_ring: IntEncoder,
pub only_parts: IntEncoder,
pub triangles: IntEncoder,
pub triangles_indexes: IntEncoder,
pub vertex: IntEncoder,
pub vertex_offsets: IntEncoder,
pub vertex_buffer_type: VertexBufferType,
}Expand description
How to encode Geometry
Fields
meta: IntEncoderEncoding settings for the geometry types (meta) stream.
geometries: IntEncoderEncoding for the geometry length stream.
rings: IntEncoderEncoding for parts length stream when rings are present.
rings2: IntEncoderEncoding for ring vertex-count stream.
no_rings: IntEncoderEncoding for parts length stream when rings are not present.
parts: IntEncoderEncoding for parts length stream (with rings) when geometry_offsets absent.
parts_ring: IntEncoderEncoding for ring lengths when geometry_offsets absent.
only_parts: IntEncoderEncoding for parts-only stream (e.g. LineString, no rings).
triangles: IntEncoderEncoding for triangles count stream (pre-tessellated polygons).
triangles_indexes: IntEncoderEncoding for triangle index buffer (pre-tessellated polygons).
vertex: IntEncoderEncoding for the vertex data stream (logical encoding is always ComponentwiseDelta if vertex_buffer_type==Vec2).
vertex_offsets: IntEncoderEncoding for vertex offsets (used when vertex_buffer_type is not Vec2).
vertex_buffer_type: VertexBufferTypeHow the vertex buffer should be encoded.
Implementations
Sourceimpl GeometryEncoder
impl GeometryEncoder
Sourcepub fn all(encoder: IntEncoder) -> Self
pub fn all(encoder: IntEncoder) -> Self
Use the provided encoder for all streams.
Sourcepub fn meta(&mut self, e: IntEncoder) -> &mut Self
pub fn meta(&mut self, e: IntEncoder) -> &mut Self
Set encoding for the geometry types (meta) stream.
Sourcepub fn geometries(&mut self, e: IntEncoder) -> &mut Self
pub fn geometries(&mut self, e: IntEncoder) -> &mut Self
Set encoding for the geometry length stream.
Sourcepub fn rings(&mut self, e: IntEncoder) -> &mut Self
pub fn rings(&mut self, e: IntEncoder) -> &mut Self
Set encoding for parts length stream when rings are present.
Sourcepub fn rings2(&mut self, e: IntEncoder) -> &mut Self
pub fn rings2(&mut self, e: IntEncoder) -> &mut Self
Set encoding for ring vertex-count stream.
Sourcepub fn no_rings(&mut self, e: IntEncoder) -> &mut Self
pub fn no_rings(&mut self, e: IntEncoder) -> &mut Self
Set encoding for parts length stream when rings are not present.
Sourcepub fn parts(&mut self, e: IntEncoder) -> &mut Self
pub fn parts(&mut self, e: IntEncoder) -> &mut Self
Set encoding for parts length stream (with rings) when geometry_offsets absent.
Sourcepub fn parts_ring(&mut self, e: IntEncoder) -> &mut Self
pub fn parts_ring(&mut self, e: IntEncoder) -> &mut Self
Set encoding for ring lengths when geometry_offsets absent.
Sourcepub fn only_parts(&mut self, e: IntEncoder) -> &mut Self
pub fn only_parts(&mut self, e: IntEncoder) -> &mut Self
Set encoding for parts-only stream (e.g. LineString, no rings).
Sourcepub fn triangles(&mut self, e: IntEncoder) -> &mut Self
pub fn triangles(&mut self, e: IntEncoder) -> &mut Self
Set encoding for triangles count stream (pre-tessellated polygons).
Sourcepub fn triangles_indexes(&mut self, e: IntEncoder) -> &mut Self
pub fn triangles_indexes(&mut self, e: IntEncoder) -> &mut Self
Set encoding for triangle index buffer (pre-tessellated polygons).
Sourcepub fn vertex(&mut self, e: IntEncoder) -> &mut Self
pub fn vertex(&mut self, e: IntEncoder) -> &mut Self
Set encoding for the vertex data stream.
Sourcepub fn vertex_offsets(&mut self, e: IntEncoder) -> &mut Self
pub fn vertex_offsets(&mut self, e: IntEncoder) -> &mut Self
Set encoding for vertex offsets (dictionary encoding).
Sourcepub fn vertex_buffer_type(&mut self, t: VertexBufferType) -> &mut Self
pub fn vertex_buffer_type(&mut self, t: VertexBufferType) -> &mut Self
Set the vertex buffer encoding type.