IdValues

Struct IdValues 

pub struct IdValues(pub Vec<Option<u64>>);
Parsed ID values as a vector of optional 64-bit unsigned integers

Tuple Fields

0: Vec<Option<u64>>

Implementations

Source

impl IdValues

pub fn values(&self) -> &[Option<u64>]

Source

impl IdValues

pub fn encode(self, encoder: IdEncoder) -> Result<Option<EncodedId>, MltError>

Encode this ID column using the given encoder, consuming self. Returns None if the ID list is empty.

pub fn encode_with_profile( &self, profile: &IdProfile, ) -> Result<(Option<EncodedId>, Option<IdEncoder>), MltError>

Encode using the profile to select the best encoder.

pub fn encode_auto( self, ) -> Result<(Option<EncodedId>, Option<IdEncoder>), MltError>

Automatically select the best encoder and encode, consuming self.