pub struct IntEncoder { /* private fields */ }Implementations
Sourceimpl IntEncoder
impl IntEncoder
pub const fn new(logical: LogicalEncoder, physical: PhysicalEncoder) -> Self
pub fn delta_fastpfor() -> IntEncoder
pub fn delta_rle_fastpfor() -> IntEncoder
pub fn delta_rle_varint() -> IntEncoder
pub fn delta_varint() -> IntEncoder
pub fn fastpfor() -> IntEncoder
pub fn plain() -> IntEncoder
pub fn rle_fastpfor() -> IntEncoder
pub fn rle_varint() -> IntEncoder
pub fn varint() -> IntEncoder
Sourcepub fn auto_u32(values: &[u32]) -> IntEncoder
pub fn auto_u32(values: &[u32]) -> IntEncoder
Automatically select the best encoder for a u32 stream.
Uses the BTRBlocks strategy:
- profile a small sample of the data to prune unsuitable candidates,
- then encode the same sample with all survivors and
- return the encoder that produces the smallest output.
FastPFOR is always preferred over VarInt when sizes are equal.
Sourcepub fn auto_u64(values: &[u64]) -> IntEncoder
pub fn auto_u64(values: &[u64]) -> IntEncoder
Automatically select the best encoder for a u64 stream.