RleMeta

Struct RleMeta 

pub struct RleMeta {
    pub runs: u32,
    pub num_rle_values: u32,
}
Metadata for RLE decoding TODO v2 optimizations:

  • runs is identical to half the size of the associated array
  • num_rle_values is identical to the size of the sum of the first half of the array. Computing checked sum should not be too expensive.

Fields

runs: u32num_rle_values: u32

Implementations

Source

impl RleMeta

pub fn decode<T: PrimInt + Debug>( self, data: &[T], dec: &mut Decoder, ) -> Result<Vec<T>, MltError>

Decode RLE (Run-Length Encoding) data. Charges the decoder for the expanded output allocation.