#[repr(u8)]pub enum PhysicalEncoding {
None = 0,
FastPFor256 = 1,
VarInt = 2,
}Expand description
Physical encoding used for a column, as stored in the tile
Variants
None = 0
FastPFor256 = 1
Preferred, tends to produce the best compression ratio and decoding performance. But currently limited to 32-bit integer.
VarInt = 2
Can produce better results in combination with a heavyweight compression scheme like Gzip.
Simple compression scheme where the encoding is easier to implement compared to FastPfor.
Implementations