pub struct RleMeta { /* private fields */ }Expand description
Metadata for RLE decoding TODO v2 optimizations:
- runs is identical to half the size of the associated array
num_rle_valuesis identical to the size of the sum of the first half of the array. Computing checked sum should not be too expensive.
Implementations