EncDec

Enum EncDec 

pub enum EncDec<Raw, Parsed> {
    Raw(Raw),
    Parsed(Parsed),
    ParsingFailed,
}
Shared wrapper for values that may still be in the original (raw) format or already parsed (but still columnar). Used by: Id, Geometry, Property, and eventually - SharedDictItem

Variants



Raw(Raw)



Parsed(Parsed)



ParsingFailed

Implementations

Source

impl<Raw: Decode<Parsed>, Parsed> EncDec<Raw, Parsed>

pub fn decode(&mut self, decoder: &mut Decoder) -> MltResult<&mut Parsed>

Decode in place, replacing the raw value with the parsed result.

pub fn into_parsed(self, decoder: &mut Decoder) -> MltResult<Parsed>

Consume and return the parsed value, decoding if currently raw.

pub fn as_parsed(&self) -> MltResult<&Parsed>

Source

impl<'a> EncDec<RawGeometry<'a>, GeometryValues>

pub fn new_raw(meta: RawStream<'a>, items: Vec<RawStream<'a>>) -> Self

Source

impl<'a> EncDec<RawId<'a>, IdValues>

pub fn new_raw(presence: RawPresence<'a>, value: RawIdValue<'a>) -> Self