GeometryEncoder

Struct GeometryEncoder 

pub struct GeometryEncoder {
Show 13 fields pub meta: IntEncoder, pub geometries: IntEncoder, pub rings: IntEncoder, pub rings2: IntEncoder, pub no_rings: IntEncoder, pub parts: IntEncoder, pub parts_ring: IntEncoder, pub only_parts: IntEncoder, pub triangles: IntEncoder, pub triangles_indexes: IntEncoder, pub vertex: IntEncoder, pub vertex_offsets: IntEncoder, pub vertex_buffer_type: VertexBufferType,
}
How to encode Geometry

Fields

meta: IntEncoder

Encoding settings for the geometry types (meta) stream.

geometries: IntEncoder

Encoding for the geometry length stream.

rings: IntEncoder

Encoding for parts length stream when rings are present.

rings2: IntEncoder

Encoding for ring vertex-count stream.

no_rings: IntEncoder

Encoding for parts length stream when rings are not present.

parts: IntEncoder

Encoding for parts length stream (with rings) when geometry_offsets absent.

parts_ring: IntEncoder

Encoding for ring lengths when geometry_offsets absent.

only_parts: IntEncoder

Encoding for parts-only stream (e.g. LineString, no rings).

triangles: IntEncoder

Encoding for triangles count stream (pre-tessellated polygons).

triangles_indexes: IntEncoder

Encoding for triangle index buffer (pre-tessellated polygons).

vertex: IntEncoder

Encoding for the vertex data stream (logical encoding is always ComponentwiseDelta if vertex_buffer_type==Vec2).

vertex_offsets: IntEncoder

Encoding for vertex offsets (used when vertex_buffer_type is not Vec2).

vertex_buffer_type: VertexBufferType

How the vertex buffer should be encoded.

Implementations

Source

impl GeometryEncoder

pub fn all(encoder: IntEncoder) -> Self

Use the provided encoder for all streams.

pub fn meta(&mut self, e: IntEncoder) -> &mut Self

Set encoding for the geometry types (meta) stream.

pub fn geometries(&mut self, e: IntEncoder) -> &mut Self

Set encoding for the geometry length stream.

pub fn rings(&mut self, e: IntEncoder) -> &mut Self

Set encoding for parts length stream when rings are present.

pub fn rings2(&mut self, e: IntEncoder) -> &mut Self

Set encoding for ring vertex-count stream.

pub fn no_rings(&mut self, e: IntEncoder) -> &mut Self

Set encoding for parts length stream when rings are not present.

pub fn parts(&mut self, e: IntEncoder) -> &mut Self

Set encoding for parts length stream (with rings) when geometry_offsets absent.

pub fn parts_ring(&mut self, e: IntEncoder) -> &mut Self

Set encoding for ring lengths when geometry_offsets absent.

pub fn only_parts(&mut self, e: IntEncoder) -> &mut Self

Set encoding for parts-only stream (e.g. LineString, no rings).

pub fn triangles(&mut self, e: IntEncoder) -> &mut Self

Set encoding for triangles count stream (pre-tessellated polygons).

pub fn triangles_indexes(&mut self, e: IntEncoder) -> &mut Self

Set encoding for triangle index buffer (pre-tessellated polygons).

pub fn vertex(&mut self, e: IntEncoder) -> &mut Self

Set encoding for the vertex data stream.

pub fn vertex_offsets(&mut self, e: IntEncoder) -> &mut Self

Set encoding for vertex offsets (dictionary encoding).

pub fn vertex_buffer_type(&mut self, t: VertexBufferType) -> &mut Self

Set the vertex buffer encoding type.