pub struct RleMeta {
pub runs: u32,
pub num_rle_values: u32,
}Expand description
Metadata for RLE decoding TODO v2 optimizations:
- runs is identical to half the size of the associated array
num_rle_valuesis identical to the size of the sum of the first half of the array. Computing checked sum should not be too expensive.
Fields
runs: u32num_rle_values: u32Implementations